@@ -3,8 +3,13 @@
 import os
 import sys
 
-from gdalconst import GA_ReadOnly
-from osgeo import ogr, osr
+try:
+    from osgeo.gdalconst import GA_ReadOnly
+    from osgeo import ogr, osr
+except ImportError:
+    from gdalconst import GA_ReadOnly
+    import ogr, osr
+
 import progressbar
 
 import cli
@@ -60,7 +65,11 @@ option.')
         with open(self.args.outfile[:-4] + '.prj', 'w') as proj_file:
             proj_file.write(spatial_ref.ExportToWkt())
 
-        extent = in_layer.GetExtent()
+        if self.args.extent:
+          extent = self.args.extent
+        else:
+          extent = in_layer.GetExtent()
+
         self.grid.create_grid(out_layer, extent,
                 num_across=self.args.num_across)
         self.count_intersections(out_layer, in_layer)
@@ -130,7 +139,6 @@ option.')
             if polygon:
                 count = polygon.GetFieldAsInteger('COUNT')
                 if count == 0:
-                    # TODO does deleting a polygon affect looping over the features?
                     target.DeleteFeature(polygon.GetFID())
                 target.SetFeature(polygon)
                 polygon.Destroy()
